@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: andrius $
-#$Date: 2020-07-01 14:12:05 +0300 (Wed, 01 Jul 2020) $ 
-#$Revision: 8085 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/AtomNeighbours.pm $
+#$Date: 2017-11-21 14:38:43 +0200 (An, 21 lapkr. 2017) $ 
+#$Revision: 5860 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/AtomNeighbours.pm $
 #------------------------------------------------------------------------------
 #*
 #  Build a list of neighbours for each atom from an atom list.
@@ -22,11 +22,9 @@ require Exporter;
 our @ISA = qw( Exporter );
 our @EXPORT_OK = qw(
     get_max_covalent_radius
-    get_max_vdw_radius
     make_neighbour_list
     neighbour_list_from_chemistry_mol
     neighbour_list_from_chemistry_openbabel_obmol
-    neighbour_list_to_graph
 );
 
 #==============================================================================#
@@ -50,27 +48,6 @@ sub get_max_covalent_radius($)
     return $max_radius;
 }
 
-#==============================================================================#
-# Find a maximal van der Waals radius in the atom property list.
-#
-# @arg: $atom_properties should be a hash of the form described in
-#       AtomProperties.pm module.
-
-sub get_max_vdw_radius($)
-{
-    my ($atom_properties) = @_;
-
-    my $max_radius = 0;
-
-    for my $atom (keys %$atom_properties) {
-        if( $max_radius < $atom_properties->{$atom}{vdw_radius} ) {
-            $max_radius = $atom_properties->{$atom}{vdw_radius};
-        }
-    }
-
-    return $max_radius;
-}
-
 #==============================================================================
 # sub make_neighbour_list
 #
@@ -88,7 +65,7 @@ sub get_max_vdw_radius($)
 #       bump.
 #
 # @arg: $atom_property_list -- a hash with atom properties, containing
-#       covalent radii; can be obtained i.e. from the AtomProperties module.
+#       covalent radii; can be obtained e.e. from the AtomProperties module.
 #
 # @ret: an array or a reference to an array with a neighbour list
 #       for each atom:
@@ -349,7 +326,6 @@ sub neighbour_list_from_chemistry_mol
 #==============================================================================
 # Generates neighbour list from Chemistry::OpenBabel::OBMol object.
 # Tested with the version 2.2.3 of OpenBabel.
-# This method is deprecated and will be removed in future releases.
 sub neighbour_list_from_chemistry_openbabel_obmol
 {
     my( $obmol ) = @_;
@@ -427,29 +403,4 @@ sub neighbour_list_from_chemistry_openbabel_obmol
     return \%neighbour_list;
 }
 
-#==============================================================================
-# Generates Graph::Undirected object from neighbour list
-sub neighbour_list_to_graph
-{
-    my( $neighbour_list ) = @_;
-
-    require Graph::Undirected;
-
-    my $graph = Graph::Undirected->new;
-    for my $atom (@{$neighbour_list->{atoms}}) {
-        my $index1 = $atom->{index};
-        if( @{$neighbour_list->{neighbours}} > $index1 &&
-            @{$neighbour_list->{neighbours}[$index1]} ) {
-            for my $index2 (@{$neighbour_list->{neighbours}[$index1]}) {
-                $graph->add_edge( $neighbour_list->{atoms}[$index1],
-                                  $neighbour_list->{atoms}[$index2] );
-            }
-        } else {
-            $graph->add_vertex( $atom );
-        }
-    }
-
-    return $graph;
-}
-
 1;
