@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: antanas $
-#$Date: 2020-05-09 22:03:46 +0300 (Sat, 09 May 2020) $
-#$Revision: 7941 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/DDL/Ranges.pm $
+#$Author: andrius $
+#$Date: 2018-01-19 11:51:05 +0200 (Pn, 19 saus. 2018) $ 
+#$Revision: 5954 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/DDL/Ranges.pm $
 #------------------------------------------------------------------------------
 #*
 #* A set of subroutines for handling ranges as defined in the Dictionary
@@ -47,7 +47,7 @@ sub parse_range
 
 ##
 # Construct a string representation of a range from the range array as
-# returned by the COD::CIF::DDL::Ranges::parse_range() subroutine.
+# returned by the COD::CIF::DDL::Range::parse_range subroutine().
 # The returned string does not have the same format as the range string
 # found in DDL files and is mainly meant to be used in audit messages.
 #
@@ -56,10 +56,10 @@ sub parse_range
 #       COD::CIF::DDL::Ranges::parse_range() subroutine.
 # @param $options
 #       Reference to a hash of options. The following options are recognised:
-#       {
+#         {
 #         # String representing the type of value ('numb' or 'char')
 #           'type'  => 'char',
-#       }
+#         }
 # @return $string
 #       A string representing the enumeration range.
 ##
@@ -81,7 +81,7 @@ sub range_to_string
 
 ##
 # Construct a string representation of a numeric range from the range array
-# as returned by the COD::CIF::DDL::Ranges::parse_range() subroutine.
+# as returned by the COD::CIF::DDL::Range::parse_range subroutine().
 # The returned string does not have the same format as the range string
 # found in DDL files and is mainly meant to be used in audit messages.
 #
@@ -105,7 +105,7 @@ sub range_to_string_numeric
 
 ##
 # Construct a string representation of a character range from the range array
-# as returned by the COD::CIF::DDL::Ranges::parse_range() subroutine.
+# as returned by the COD::CIF::DDL::Range::parse_range subroutine().
 # The returned string does not have the same format as the range string
 # found in DDL files and is mainly meant to be used in audit messages.
 #
@@ -120,9 +120,9 @@ sub range_to_string_char
     my ($range) = @_;
 
     my $string;
-    $string  = (defined $range->[0] ? "['$range->[0]'" : '[<any>');
+    $string  = (defined $range->[0] ? "[$range->[0]" : '[<any>');
     $string .= ', ';
-    $string .= (defined $range->[1] ? "'$range->[1]']" : '<any>]');
+    $string .= (defined $range->[1] ? "$range->[1]]" : '<any>]');
 
     return $string;
 }
@@ -134,16 +134,16 @@ sub range_to_string_char
 #       Value to be checked.
 # @param $param
 #       Parameter hash with the following keys:
-#       {
-#         # String, representing the type of value ('numb' or 'char')
+#         {
 #           'type'  => 'char',
-#         # Reference to a range array as returned by the
-#         # COD::CIF::DDL::Ranges::parse_range() subroutine
-#           'range' => [0, 10],
-#         # Standard deviation to be used when comparing numeric values
-#         # (3 sigma rule). If sigma is not provided, values are compared
-#         # disregarding the standard deviation
-#           'sigma  => 0.1,
+#                String, representing the type of value ('numb' or 'char').
+#           'range' => [0, 10]
+#                Reference to a range array as returned by the
+#                COD::CIF::DDL::Ranges::parse_range() subroutine.
+#           'sigma  => 0.1
+#               Standard deviation to be used when comparing numeric values
+#               (3 sigma rule). If sigma is not provided, values are compared
+#               disregarding the standard deviation.
 #         }
 # @return
 #       -1 if no ranges were provided for the value;
@@ -176,15 +176,15 @@ sub is_in_range
 #       Value to be checked.
 # @param $param
 #       Parameter hash with the following keys:
-#       {
-#         # Reference to a range array as returned by the
-#         # COD::CIF::DDL::Ranges::parse_range() subroutine
-#           'range' => [0, 10],
-#         # Standard deviation to be used when comparing numeric values
-#         # (3 sigma rule). If sigma is not provided, values are compared
-#         # disregarding the standard deviation
-#           'sigma  => 0.1,
-#       }
+#         {
+#           'range' => [0, 10]
+#                Reference to a range array as returned by the
+#                COD::CIF::DDL::Ranges::parse_range() subroutine.
+#           'sigma  => 0.1
+#               Standard deviation to be used when comparing numeric values
+#               (3 sigma rule). If sigma is not provided, values are compared
+#               disregarding the standard deviation.
+#         }
 # @return
 #        0 if the value is out of the provided range or is not a number
 #          at all;
@@ -223,13 +223,13 @@ sub is_in_range_numeric
 #       Value to be checked.
 # @param $param
 #       Parameter hash with the following keys:
-#       {
-#         # Reference to a range array as returned by the
-#         # COD::CIF::DDL::Ranges::parse_range() subroutine.
-#           'range' => ['a', 'c'],
-#       }
+#         {
+#           'range' => [a, c]
+#                Reference to a range array as returned by the
+#                COD::CIF::DDL::Ranges::parse_range() subroutine.
+#         }
 # @return
-#        0 if the value is out of the provided range,
+#        0 if the value is out of the provided range;
 #        1 if the value is in the provided range.
 ##
 sub is_in_range_char
@@ -239,9 +239,9 @@ sub is_in_range_char
     my $range = $param->{'range'};
 
     if(
-        ( !defined $range->[0] || $value ge $range->[0] )
+        ( !exists $param->[0] || $value ge $range->[0] )
         &&
-        ( !defined $range->[1] || $value le $range->[1] )
+        ( defined $range->[1] || $value le $range->[1] )
     ) {
         return 1;
     }
