@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: antanas $
-#$Date: 2020-05-09 22:26:29 +0300 (Sat, 09 May 2020) $ 
-#$Revision: 7942 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/DDL/Validate.pm $
+#$Author: andrius $
+#$Date: 2019-01-21 09:23:55 +0200 (Pr, 21 saus. 2019) $ 
+#$Revision: 6648 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/DDL/Validate.pm $
 #------------------------------------------------------------------------------
 #*
 #* A set of subroutines used to validate CIF files against ontologies expressed
@@ -43,7 +43,13 @@ sub check_enumeration_set
 {
     my ($values, $enum_set, $options) = @_;
 
+    my @validation_messages;
+
+    my $ignore_case  = $options->{'ignore_case'};
+    my $treat_as_set = $options->{'treat_as_set'};
+
     my $enum_regex = build_enum_regex( $enum_set, $options );
+
     my @is_proper_enum = map { $_ !~ m/$enum_regex/s } @{$values};
 
     return \@is_proper_enum;
