@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-05 15:52:27 +0200 (Tue, 05 Nov 2019) $ 
-#$Revision: 7303 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/Data.pm $
+#$Date: 2018-07-17 15:25:13 +0300 (An, 17 liep. 2018) $ 
+#$Revision: 6309 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Data.pm $
 #------------------------------------------------------------------------------
 #*
 #  Common subroutines for extracting data/creating data structures from
@@ -18,7 +18,6 @@ use COD::Spacegroups::Names;
 use COD::CIF::Tags::Manage qw( has_special_value
                                has_unknown_value
                                has_inapplicable_value );
-use List::MoreUtils qw( uniq );
 
 require Exporter;
 our @ISA = qw( Exporter );
@@ -29,7 +28,6 @@ our @EXPORT_OK = qw(
     get_content_encodings
     get_source_data_block_name
     get_symmetry_operators
-    space_group_data_names
 );
 
 my %sg_name_abbrev =
@@ -72,11 +70,11 @@ sub get_cell
         if( exists $values->{$cif_tag} &&
             defined $values->{$cif_tag}[0] ) {
             push(@cell_lengths_and_angles, $values->{$cif_tag}[0]);
-            $cell_lengths_and_angles[-1] =~ s/\([0-9]+\)$//;
+            $cell_lengths_and_angles[-1] =~ s/\(\d+\)$//;
         } elsif( $options->{silent} ) {
             push(@cell_lengths_and_angles, undef);
         } else {
-            die "ERROR, cell length data item '$cif_tag' was not found" . "\n";
+            die "ERROR, cell length data item '$cif_tag' not present" . "\n";
         }
     }
 
@@ -88,11 +86,11 @@ sub get_cell
         if( exists $values->{$cif_tag} &&
             defined $values->{$cif_tag}[0] ) {
             push( @cell_lengths_and_angles, $values->{$cif_tag}[0] );
-            $cell_lengths_and_angles[-1] =~ s/\([0-9]+\)$//;
+            $cell_lengths_and_angles[-1] =~ s/\(\d+\)$//;
         } elsif( $options->{silent} ) {
             push(@cell_lengths_and_angles, undef);
         } else {
-            warn( "WARNING, cell angle data item '$cif_tag' was not found -- "
+            warn( "WARNING, cell angle data item '$cif_tag' not present -- "
                 . "taking default value 90 degrees\n" );
             push( @cell_lengths_and_angles, 90 );
         }
@@ -101,57 +99,12 @@ sub get_cell
     return @cell_lengths_and_angles;
 }
 
-# Returns a list of space group data names grouped by the type of data
-# piece they represent. In fact, data items in each of the groups
-# should be treated as alternates.
-sub space_group_data_names
-{
-    return {
-        'hall' => [
-                    '_space_group_name_Hall',
-                    '_symmetry_space_group_name_Hall',
-                  ],
-        'hermann_mauguin' => [
-                    '_space_group_name_H-M_alt',
-                    '_symmetry_space_group_name_H-M',
-                    '_space_group.name_H-M_full',
-                  ],
-        'number' => [
-                    '_space_group_IT_number',
-                    '_symmetry_Int_Tables_number',
-                  ],
-        'symop_ids' => [
-                    '_space_group_symop_id',
-                    '_symmetry_equiv_pos_site_id'
-                  ],
-        'symops' => [
-                    '_space_group_symop_operation_xyz',
-                    '_symmetry_equiv_pos_as_xyz'
-                  ],
-        'ssg_name' => [
-                    '_space_group_ssg_name'
-                  ],
-        'ssg_name_IT' => [
-                    '_space_group_ssg_name_IT',
-                  ],
-        'ssg_name_WJJ' => [
-                    '_space_group_ssg_name_WJJ',
-                  ],
-        'ssg_symop_ids' => [
-                    '_space_group_symop_ssg_id'
-                  ],
-        'ssg_symops' => [
-                    '_space_group_symop_ssg_operation_algebraic'
-                  ]
-    };
-}
-
 ##
 # Constructs a structure containing symmetry information using only the data
 # present in the data block.
 # @param $values
 #       The 'values' hash extracted from the CIF structure as returned by the
-#       COD::CIF::Parser.
+#       CIF::COD::Parser.
 # @return $sg_data
 #       A structure containing the symmetry information present in the data
 #       block. Example of the returned data structure:
@@ -162,26 +115,20 @@ sub space_group_data_names
 #           'number'          => 2,
 #           'symop_ids'       =>
 #                       [
-#                         1,
+#                         1
 #                         2
 #                       ],
 #           'symops' =>
 #                       [
 #                          'x, y, z',
 #                          '-x, -y, -z'
-#                       ],
+#                       ];
 #           'tags' => {
-#               'hermann_mauguin' => '_space_group_name_H-M_alt',
-#               'hall'      => '_space_group_name_Hall',
-#               'number'    => '_space_group_IT_number',
-#               'symop_ids' => '_space_group_symop_id',
+#               'hermann_mauguin' => '_space_group_name_H-M_alt'
+#               'hall'      => '_space_group_name_Hall'
+#               'number'    => '_space_group_IT_number'
+#               'symop_ids' => '_space_group_symop_id'
 #               'symops'    => '_space_group_symop_operation_xyz'
-#           },
-#           'tags_all' => {
-#               'hermann_mauguin' => [
-#                                       '_space_group_name_H-M_alt',
-#                                       '_symmetry_space_group_name_H-M',
-#                                    ],
 #           }
 #       }
 #
@@ -219,16 +166,58 @@ sub space_group_data_names
 #       'tags'
 #                           A hash that records the names of the data items
 #                           from which the space group data values were taken.
-#       'tags_all'
-#                           A hash of arrays that records the names of the
-#                           data items from which the space group data values
-#                           were taken.
 ##
 sub get_sg_data
 {
     my ($data_block) = @_;
 
-    my $sg_data_names = space_group_data_names();
+    my $sg_data_names = {
+        'hall' => [
+                    '_space_group_name_Hall',
+                    '_space_group_name_hall',
+                    '_symmetry_space_group_name_Hall',
+                    '_symmetry_space_group_name_hall',
+                  ],
+        'hermann_mauguin' => [
+                    '_space_group_name_H-M_alt',
+                    '_space_group_name_h-m_alt',
+                    '_symmetry_space_group_name_H-M',
+                    '_symmetry_space_group_name_h-m',
+                    '_space_group.name_H-M_full',
+                    '_space_group.name_h-m_full'
+                  ],
+        'number' => [
+                    '_space_group_IT_number',
+                    '_space_group_it_number',
+                    '_symmetry_Int_Tables_number',
+                    '_symmetry_int_tables_number'
+                  ],
+        'symop_ids' => [
+                    '_space_group_symop_id',
+                    '_symmetry_equiv_pos_site_id'
+                  ],
+        'symops' => [
+                    '_space_group_symop_operation_xyz',
+                    '_symmetry_equiv_pos_as_xyz'
+                  ],
+        'ssg_name' => [
+                    '_space_group_ssg_name'
+                  ],
+        'ssg_name_IT' => [
+                    '_space_group_ssg_name_IT',
+                    '_space_group_ssg_name_it'
+                  ],
+        'ssg_name_WJJ' => [
+                    '_space_group_ssg_name_WJJ',
+                    '_space_group_ssg_name_wjj'
+                  ],
+        'ssg_symop_ids' => [
+                    '_space_group_symop_ssg_id'
+                  ],
+        'ssg_symops' => [
+                    '_space_group_symop_ssg_operation_algebraic'
+                  ]
+    };
 
     my %looped_sg_data_types = map { $_ => $_ }
         qw( symop_ids symops ssg_symop_ids ssg_symops );
@@ -236,41 +225,15 @@ sub get_sg_data
     my $values = $data_block->{'values'};
     my %sg_data;
     for my $info_type ( keys %{$sg_data_names} ) {
-        if( exists $looped_sg_data_types{$info_type} ) {
-            # looped tag
-            foreach ( get_tag_variants( @{$sg_data_names->{$info_type}} ) ) {
-                next if !exists $values->{$_};
+        foreach ( @{$sg_data_names->{$info_type}} ) {
+            if ( exists $values->{$_} &&
+                 !has_special_value($data_block, $_, 0) ) {
                 $sg_data{$info_type} = $values->{$_};
                 $sg_data{'tags'}{$info_type} = $_;
-                $sg_data{'tags_all'}{$info_type} = [ $_ ];
-                last;
-            }
-        } else {
-            # single tag
-            my %sg_values = map { $_ => $values->{$_}[0] }
-                            grep { exists $values->{$_} &&
-                                   !has_special_value( $data_block, $_, 0 ) }
-                                 get_tag_variants( @{$sg_data_names->{$info_type}} );
-            foreach ( get_tag_variants( @{$sg_data_names->{$info_type}} ) ) {
-                next if !exists $sg_values{$_};
-                if( !exists $sg_data{$info_type} ) {
-                    $sg_data{$info_type} = $sg_values{$_};
-                    $sg_data{'tags'}{$info_type} = $_;
-                } elsif( $sg_data{$info_type} ne $sg_values{$_} ) {
-                    next;
+                if ( !exists $looped_sg_data_types{$info_type} ) {
+                    $sg_data{$info_type} = $sg_data{$info_type}[0];
                 }
-                push @{$sg_data{'tags_all'}{$info_type}}, $_;
-            }
-            if( uniq( values %sg_values ) > 1 ) {
-                my @alt_tags = grep { exists $sg_values{$_} }
-                                 get_tag_variants( @{$sg_data_names->{$info_type}} );
-
-                warn 'WARNING, data items [' .
-                     ( join ', ', map { "'$_'" } @alt_tags ) .
-                     '] refer to the same piece of information, ' .
-                     'but have differing values [' .
-                     ( join ', ', map { "'$sg_values{$_}'" } @alt_tags ) .
-                     "] -- the '$sg_data{$info_type}' value will be used\n";
+                last;
             }
         }
     }
@@ -295,7 +258,7 @@ sub get_symmetry_operators($)
     if( !defined $sym_data && defined $sg->{'hall'} ) {
         $sym_data = lookup_space_group('hall', $sg->{'hall'});
         if( !defined $sym_data ) {
-            warn "WARNING, data item '$sg->{'tags'}{'hall'}' value " .
+            warn "WARNING, the '$sg->{'tags'}{'hall'}' data item value " .
                  "'$sg->{'hall'}' was not recognised as a space group name\n";
         }
     }
@@ -303,7 +266,7 @@ sub get_symmetry_operators($)
     if( !defined $sym_data && defined $sg->{'hermann_mauguin'} ) {
         $sym_data = lookup_space_group('hermann_mauguin', $sg->{'hermann_mauguin'});
         if( !defined $sym_data ) {
-            warn "WARNING, data item '$sg->{'tags'}{'hermann_mauguin'}' " .
+            warn "WARNING, the '$sg->{'tags'}{'hermann_mauguin'}' data item " .
                  "value '$sg->{'hermann_mauguin'}' was not recognised as a " .
                  "space group name\n";
         }
@@ -325,7 +288,7 @@ sub get_symmetry_operators($)
                 $sym_data = lookup_space_group("hermann_mauguin", $h_m);
 
                 if( !defined $sym_data ) {
-                    warn "WARNING, data item '$tag' value '$ssg_name' " .
+                    warn "WARNING, the '$tag' data item value '$ssg_name' " .
                          "yielded H-M symbol '$h_m' which is not in our tables\n";
                 } else {
                     last
@@ -339,10 +302,10 @@ sub get_symmetry_operators($)
     }
 
     if( !defined $sym_data ) {
-        die 'ERROR, neither symmetry operation data item values, '
+        die 'ERROR, neither symmetry operator data item values, '
           . 'nor Hall space group name, '
           . 'nor Hermann-Mauguin space group name '
-          . "could be processed to acquire symmetry operations\n";
+          . "could be processed to acquire symmetry operators\n";
     }
 
     return $symops;
@@ -484,7 +447,7 @@ sub get_formula_units_z
     return $data_block->{'values'}{'_cell_formula_units_Z'}[0];
 }
 
-# TODO: this subroutine should eventually be moved to the COD::CIF::Data::Check
+# TODO: this subroutine should eventually be moved to the CIF::COD::Data::Check
 # module, but for now it is kept here to avoid establishing an explicit
 # interface
 sub check_formula_units_z
@@ -497,17 +460,17 @@ sub check_formula_units_z
     # into a separate subroutine
     my $message;
     if ( !exists $data_block->{'values'}{$data_name} ) {
-        $message = "data item '$data_name' was not found";
+        $message = "the $data_name data item is missing";
     } elsif ( has_unknown_value( $data_block, $data_name, 0 ) ) {
-        $message = "data item '$data_name' value is marked as unknown ('?')";
+        $message = "the $data_name item value is marked as unknown ('?')";
     } elsif ( has_inapplicable_value( $data_block, $data_name, 0 ) ) {
-        $message = "data item '$data_name' value is marked as not applicable ('.')";
+        $message = "the $data_name item value is marked as not applicable ('.')";
     };
 
     if ( !defined $message ) {
         if ( $data_block->{'values'}{$data_name}[0] !~
                                                 /^\+?[0-9]*[1-9][0-9]*$/ ) {
-            $message = "data item '$data_name' value '" .
+            $message = "the $data_name data item value '" .
                        $data_block->{'values'}{$data_name}[0] .
                        '\' is not a natural number';
         }
@@ -516,10 +479,4 @@ sub check_formula_units_z
     return defined $message ? [ $message ] : [];
 }
 
-sub get_tag_variants
-{
-    my( @tags ) = @_;
-    return map { $_ ne lc $_ ? ( $_, lc $_ ) : ( $_ ) } @tags;
-}
-
 1;
