@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: andrius $
-#$Date: 2020-07-01 17:55:09 +0300 (Wed, 01 Jul 2020) $
-#$Revision: 8090 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/Data/CODNumbers.pm $
+#$Date: 2018-10-11 14:59:55 +0300 (Kt, 11 spal. 2018) $
+#$Revision: 6469 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Data/CODNumbers.pm $
 #------------------------------------------------------------------------------
 #*
 #  Find COD numbers of duplicate structures.
@@ -14,7 +14,7 @@ use strict;
 use warnings;
 use DBI;
 use File::Basename qw( basename );
-use List::MoreUtils qw( any uniq );
+use List::MoreUtils qw( uniq );
 use COD::Formulae::Parser::AdHoc;
 use COD::DateTime qw( parse_datetime );
 use COD::CIF::Data::CellContents qw( cif_cell_contents );
@@ -117,22 +117,24 @@ my $db_fields2tags = {
 #         # Each duplicate entry is identified by its database ID (i.e. COD ID)
 #         # and described by a data structure as returned by the
 #         # 'get_database_entries()' subroutine:
-#           'duplicates' => {
-#               '1100003' => {
-#                   'id'           => '1100003',
-#                   'filename'     => '1100003',
-#                   'bibliography' => { ... },
-#                   'cell'         => { ... },
-#                   'sigcell'      => { ... },
-#                   'pressure'     => { ... },
-#                   'temperature'  => { ... },
-#                   'history'      => { ... },
-#                   'source'       => { ... },
+#           'duplicates' =>
+#               {
+#                 '1100003' =>
+#                  {
+#                    'id'           => '1100003',
+#                    'filename'     => '1100003',
+#                    'bibliography' => { ... },
+#                    'cell'         => { ... },
+#                    'sigcell'      => { ... },
+#                    'pressure'     => { ... },
+#                    'temperature'  => { ... },
+#                    'history'      => { ... },
+#                    'source'       => { ... },
 #                    ...
-#               },
-#               ...
+#                  },
+#                  ...
+#               }
 #           }
-#       }
 ##
 sub fetch_duplicates_from_database
 {
@@ -218,152 +220,23 @@ sub fetch_duplicates
 
 #------------------------------------------------------------------------------
 
-##
-# Builds a crystal structure description that contains sufficient information
-# to determine if the given structure is a duplicate of another structure
-# according to the COD criteria [1].
-#
-# @source [1]
-#       https://wiki.crystallography.net/duplicate_entry
-#
-# @param $dataset
-#       Reference to a data block as returned by the COD::CIF::Parser.
-# @param $file
-#       Name of the parsed CIF file that contains the structure.
-# @param $index
-#       Arbitrary index that is used by the fetch_duplicates() subroutine
-#       to order entries while searching for duplicates.
-# @return
-#       Reference to a data structure of the following form:
-#       {
-#         # Data block code of the CIF data block that contains the structure
-#           'id' => '1000000',
-#         # Name of the parsed CIF file that contains the structure
-#           'filename' => '1000000.cif',
-#         # Arbitrary index that is used by the fetch_duplicates()
-#         # subroutine to order entries while searching for duplicates
-#           'index' => 0,
-#         # Summary chemical formula of the compound as
-#         # explicitly provided in the original file
-#           'chemical_formula_sum' => 'H2 O',
-#         # Summary chemical formula of the compound
-#         # calculated from the crystallographic data
-#           'calc_formula' => 'H2 O',
-#         # Summaary chemical formula of the crystal cell
-#         # calculated from the crystallographic data (Z = 1)
-#           'cell_formula' => 'H8 O4',
-#         # Crystal cell parameter values without
-#         # the standard uncertainty values (see 'sigcell)
-#           'cell' => {
-#               '_cell_length_a' => 7.53,
-#               '_cell_length_b' => 7.53,
-#               '_cell_length_c' => 7.53
-#               '_cell_angle_alpha' => 90,
-#               '_cell_angle_beta' => 90,
-#               '_cell_angle_gamma' => 90,
-#           },
-#         # Standard uncertainty values of crystal cell
-#         # parameter values (see 'cell)
-#           'sigcell' => {
-#               '_cell_length_a' => 2,
-#               '_cell_length_b' => 3,
-#               '_cell_length_c' => 4,
-#               '_cell_angle_alpha' => 1,
-#               '_cell_angle_beta'  => 1,
-#               '_cell_angle_gamma' => 1,
-#           },
-#         # Bibliographical references to the original
-#         # publication describing the structure
-#           'bibliography' => {
-#                '_journal_name_full' => 'Journal',
-#                '_journal_year' => '2000',
-#                '_journal_volume' => '5',
-#                '_journal_issue' => '6',
-#                '_journal_page_first' => '1',
-#                '_journal_page_last' => '2',
-#                '_journal_paper_doi' => '10.1186/s13321-018-0279-6',
-#           },
-#         # Sample preparation details as provided in the original file
-#           'history' => {
-#                '_exptl_crystal_pressure_history' => 'Held under pressure',
-#                '_exptl_crystal_thermal_history' => 'Treated in flames',
-#           },
-#         # Pressure under which the crystal was measured
-#           'pressure' => {
-#                '_cell_measurement_pressure' => 101,
-#                '_cell_measurement_pressure_gPa' => ...,
-#                '_cell_wave_vectors_pressure_max' => ...,
-#                '_cell_wave_vectors_pressure_min' => ...,
-#                '_diffrn_ambient_pressure' => ...,
-#                '_diffrn.ambient_pressure' => ...,
-#                '_diffrn.ambient_pressure_esd' => ...,
-#                '_diffrn_ambient_pressure_gPa' => ...,
-#                '_diffrn_ambient_pressure_gt' => ...,
-#                '_diffrn.ambient_pressure_gt' => ...,
-#                '_diffrn_ambient_pressure_lt' => ...,
-#                '_diffrn.ambient_pressure_lt' => ...,
-#                '_pd_prep_pressure' => ...,
-#           },
-#         # Temperature under which the crystal was measured
-#           'temperature' => {
-#                '_cell_measurement_temperature' => 293.2
-#                '_cell_measurement_temperature_C' => ...,
-#                '_diffrn_ambient_temperature' => ...,
-#                '_diffrn_ambient_temperature_C' => ...,
-#                '_diffrn_ambient_temperature_gt' => ...,
-#                '_diffrn_ambient_temperature_lt' => ...,
-#                '_pd_prep_temperature' => ...,
-#           },
-#         # Compound source
-#           'source' => {
-#                '_chemical_compound_source' => 'The moon',
-#           },
-#         # COD IDs of COD entries that are explicitly marked
-#         # as enantiomers of this structures
-#           'related_enantiomer_entries' => [
-#               '1000001',
-#               '1000002',
-#           ],
-#         # COD ID of the COD entry that is explicitly
-#         # marked as the optimal solution of this structure
-#           'related_optimal' => '1000003',
-#         # 'yes'/'no' value denoting if the structure is suboptimal
-#           'suboptimal' => 'yes',
-# FIXME: remove the deprecated fields in the next major release
-# # Deprecated fields that should not be used and that
-# # will be removed in the next major release
-#         # COD IDs of COD entries that are explicitly marked
-#         # as enantiomers of this structures. The field was
-#         # replaced by the 'related_enantiomer_entries' field
-#           'enantiomer' => {
-#               '_cod_related_enantiomer_entry.code' => '1000000', 
-#               '_cod_related_enantiomer_entry_code' => '1000000',
-#               '_cod_enantiomer_of' => '1000000',
-#           },
-#       }
-##
 sub cif_fill_data
 {
-    my ( $dataset, $file, $index, $options ) = @_;
-
-    $options = {} unless $options;
-    my( $use_attached_hydrogens ) = (
-        $options->{use_attached_hydrogens},
-    );
+    my ( $dataset, $file, $index ) = @_;
 
     my %structure;
 
-    my $values = $dataset->{'values'};
-    my $sigmas = $dataset->{'precisions'};
-    my $id = $dataset->{'name'};
+    my $values = $dataset->{values};
+    my $sigmas = $dataset->{precisions};
+    my $id = $dataset->{name};
 
     return if !defined $id;
-    $structure{'id'} = $id;
-    $structure{'filename'} = basename( $file );
-    $structure{'index'} = $index;
+    $structure{id} = $id;
+    $structure{filename} = basename( $file );
+    $structure{index} = $index;
 
-    if( defined $values->{'_chemical_formula_sum'} ) {
-        my $formula = $values->{'_chemical_formula_sum'}[0];
+    if( defined $values->{_chemical_formula_sum} ) {
+        my $formula = $values->{_chemical_formula_sum}[0];
 
         if( $formula ne '?' ) {
 
@@ -386,43 +259,42 @@ sub cif_fill_data
                 for( @formula_parser_warnings ) {
                     print STDERR $_;
                 }
-                warn "WARNING, could not parse formula '$formula' -- "
-                   . 'resorting to simple split routine' . "\n";
+                warn "WARNING, could not parse formula '$formula' "
+                   . "resorting to simple split routine\n";
                 $formula = join ' ', sort {$a cmp $b} split( ' ', $formula );
             }
         }
-        $structure{'chemical_formula_sum'} = $formula;
+        $structure{chemical_formula_sum} = $formula;
     }
 
     my $calc_formula;
     eval {
-        $calc_formula = cif_cell_contents( $dataset,
-                                           undef,
-                                           $use_attached_hydrogens );
+        $calc_formula = cif_cell_contents( $dataset, undef );
     };
     if ($@) {
-        # ERRORs that originate within the function are downgraded to warnings
+        # ERRORs that originated within the function are downgraded to warnings
         my $error = $@;
         $error =~ s/[A-Z]+, //;
         chomp $error;
         warn "WARNING, summary formula could not be calculated -- $error\n";
     };
-    $structure{'calc_formula'} = $calc_formula if defined $calc_formula;
+    $structure{calc_formula} = $calc_formula
+        if defined $calc_formula;
+
 
     my $cell_formula;
     eval {
-        $cell_formula = cif_cell_contents( $dataset,
-                                           1,
-                                           $use_attached_hydrogens );
+        $cell_formula = cif_cell_contents( $dataset, 1 );
     };
     if ($@) {
-        # ERRORs that originate within the function are downgraded to warnings
+        # ERRORs that originated within the function are downgraded to warnings
         my $error = $@;
         $error =~ s/[A-Z]+, //;
         chomp $error;
         warn "WARNING, unit cell summary formula could not be calculated -- $error\n";
     };
-    $structure{'cell_formula'} = $cell_formula if defined $cell_formula;
+    $structure{cell_formula} = $cell_formula
+        if defined $cell_formula;
 
     for my $key ( qw( _cell_length_a
                       _cell_length_b
@@ -456,8 +328,8 @@ sub cif_fill_data
         ],
         'history' => [
             qw(
-                _exptl_crystal_pressure_history
-                _exptl_crystal_thermal_history
+                 _exptl_crystal_pressure_history
+                 _exptl_crystal_thermal_history
             )
         ],
         'pressure' => [
@@ -488,14 +360,8 @@ sub cif_fill_data
                 _pd_prep_temperature
             )
         ],
-        # FIXME: the 'enantiomer' field should be removed prior to a major
-        # release since it was replaced with the 'related_enantiomer_entries'
-        # field. The new field takes into consideration that there might be
-        # more than one related enantiomer entry.
         'enantiomer' => [
             qw(
-                _cod_related_enantiomer_entry.code
-                _cod_related_enantiomer_entry_code
                 _cod_enantiomer_of
             )
         ],
@@ -517,25 +383,13 @@ sub cif_fill_data
         }
     }
 
-    my $enantiomer_entry_codes = get_related_enantiomer_entry_codes( $dataset );
-    if (@{$enantiomer_entry_codes}) {
-        $structure{'related_enantiomer_entries'} = $enantiomer_entry_codes;
-    }
-
     my $value = get_aliased_value($values,
-                    [ qw( _cod_related_optimal_entry.code
-                          _cod_related_optimal_entry_code
-                          _cod_related_optimal_struct
+                    [ qw( _cod_related_optimal_struct
                           _[local]_cod_related_optimal_struct ) ]);
     if (defined $value) {
         $structure{'related_optimal'} = $value;
     }
 
-    # FIXME: whether a structure is suboptimal can be judged not only from
-    # the value of the _cod_suboptimal_structure data item, but also from
-    # the presence of related optimal entry data items (the preferred way).
-    # This type of functionality is supplied by the
-    # COD::CIF::Data::CODFlags::is_suboptimal() subroutine
     $value = get_aliased_value($values,
                 [ qw( _cod_suboptimal_structure
                       _[local]_cod_suboptimal_structure ) ] );
@@ -546,35 +400,6 @@ sub cif_fill_data
     return \%structure;
 }
 
-##
-# Returns the COD IDs of entries that are explicitly referenced as
-# enantiomers in the provided data block.
-#
-# @param $data_block
-#       Reference to data block as returned by the COD::CIF::Parser.
-# @return \@related_enantiomer_entry_codes
-#       Reference to an array of COD IDs.
-##
-sub get_related_enantiomer_entry_codes
-{
-    my ($data_block) = @_;
-
-    my @related_enantiomer_tags = qw(
-        _cod_related_enantiomer_entry.code
-        _cod_related_enantiomer_entry_code
-        _cod_enantiomer_of
-    );
-
-    my @related_enantiomer_entry_codes;
-    for my $tag (@related_enantiomer_tags) {
-        next if !defined $data_block->{'values'}{$tag};
-        push @related_enantiomer_entry_codes, @{$data_block->{'values'}{$tag}};
-    }
-    @related_enantiomer_entry_codes = uniq @related_enantiomer_entry_codes;
-
-    return \@related_enantiomer_entry_codes;
-}
-
 #------------------------------------------------------------------------------
 
 sub get_cell($)
@@ -782,8 +607,8 @@ sub have_equiv_category_values
         my $val_1 = $entry_1->{$category}{$tag};
         my $val_2 = $entry_2->{$category}{$tag};
         if ( $val_1 =~ /^${number}$/o || $val_2 =~ /^${number}$/o ) {
-            $val_1 =~ s/\([0-9]+\)$//;
-            $val_2 =~ s/\([0-9]+\)$//;
+            $val_1 =~ s/\(\d+\)$//;
+            $val_2 =~ s/\(\d+\)$//;
             return 0 if ( $val_1 != $val_2 )
         } else {
             $val_1 =~ s/^\s+|\s+$//g;
@@ -984,20 +809,28 @@ sub entries_are_the_same
         }
     };
 
-    return 0 if entries_are_enantiomers( $entry1, $entry2 );
-
     # FIXME: the logic involving optimal/suboptimal structures seems
     # to be broken. For example, structures that contain the
     # _cod_suboptimal_structure data are not even recognised as themselves
     # by the cif_cod_numbers script
-    return 0 if defined $entry1->{'suboptimal'} && $entry1->{'suboptimal'} eq 'yes';
-    return 0 if defined $entry2->{'suboptimal'} && $entry2->{'suboptimal'} eq 'yes';
+    my $are_the_same =
+        have_equiv_lattices( $entry1, $entry2, \%options ) &&
+        have_equiv_conditions( $entry1, $entry2 ) &&
+        (!defined $entry1->{suboptimal} || $entry1->{suboptimal} ne 'yes') &&
+        (!defined $entry2->{suboptimal} || $entry2->{suboptimal} ne 'yes');
 
-    return 0 if !have_equiv_lattices( $entry1, $entry2, \%options );
-    return 0 if !have_equiv_conditions( $entry1, $entry2 );
+    # This is a temporary statement that should be rewritten once the
+    # issues involving the suboptimal structures are resolved
+    return 0 if (!$are_the_same);
 
-    # FIXME: the related optimal check is parameter position dependent:
+    # FIXME: the enantiomer and related optimal checks are parameter position
+    # dependent:
     # ( entries_are_the_same($s1, $s2) != entries_are_the_same($s1, $s2) )
+    if ( defined $entry1->{'enantiomer'}{'_cod_enantiomer_of'} &&
+         $entry1->{'enantiomer'}{'_cod_enantiomer_of'} eq $entry2->{'id'} ) {
+        return 0;
+    }
+
     if ( defined $entry1->{'related_optimal'} &&
          $entry1->{'related_optimal'} eq $entry2->{'id'} &&
          defined $entry1->{'suboptimal'} &&
@@ -1023,74 +856,6 @@ sub entries_are_the_same
     return 1;
 }
 
-##
-# Evaluates if at least one of the entries is explicitly marked by the COD
-# maintainers as an enantiomer of the other. 
-#
-# @param $entry_1
-#       Data structure of the first entry as returned by the 'cif_fill_data()'
-#       or the 'get_database_entries()' subroutines.
-# @param $entry_2
-#       Data structure of the second entry as returned by the 'cif_fill_data()'
-#       or the 'get_database_entries()' subroutines.
-# @return
-#       '1' if at least one of the entries is marked as an enantiomer of the other,
-#       '0' otherwise.
-##
-sub entries_are_enantiomers
-{
-    my ($entry_1, $entry_2) = @_;
-
-    return 1 if is_related_enantiomer_entry($entry_1, $entry_2);
-    return 1 if is_related_enantiomer_entry($entry_2, $entry_1);
-
-    return 0;
-}
-
-##
-# Evaluates if the main entry references the related entry as an enantiomer.
-#
-# @param $main_entry
-#       Data structure of the main entry as returned by the 'cif_fill_data()'
-#       or the 'get_database_entries()' subroutines.
-# @param $related_entry
-#       Data structure of the relared entry as returned by the 'cif_fill_data()'
-#       or the 'get_database_entries()' subroutines.
-# @return
-#       '1' if the main entry references the related entry as an enantiomer,
-#       '0' otherwise.
-##
-sub is_related_enantiomer_entry
-{
-    my ($main_entry, $related_entry) = @_;
-
-    my @enantiomer_entries;
-
-    # FIXME: the following code block should be removed once
-    # the 'enantiomer' entry field is properly deprecated and removed 
-    # BEGIN
-    if (defined $main_entry->{'enantiomer'}) {
-        my @enantiomer_tags = qw(
-            _cod_related_enantiomer_entry.code
-            _cod_related_enantiomer_entry_code
-            _cod_enantiomer_of
-        );
-        for my $tag (@enantiomer_tags) {
-            next if !defined $main_entry->{'enantiomer'}{$tag};
-            push @enantiomer_entries, $main_entry->{'enantiomer'}{$tag};
-        }
-    }
-    # END
-
-    if (exists $main_entry->{'related_enantiomer_entries'}) {
-        push @enantiomer_entries, @{$main_entry->{'related_enantiomer_entries'}};
-    }
-
-    my $is_enantiomer = any { $_ eq $related_entry->{'id'} } @enantiomer_entries;
-
-    return $is_enantiomer ? 1 : 0;
-}
-
 ##
 # Connects to a database using the provided parameters. This subroutine
 # acts as a wrapper for the 'DBI->connect' subroutine.
