@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-04-06 02:39:53 +0300 (Sat, 06 Apr 2019) $
-#$Revision: 6896 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/Data/CODPredepositionCheck.pm $
+#$Date: 2018-07-02 15:35:08 +0300 (Pr, 02 liep. 2018) $
+#$Revision: 6270 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Data/CODPredepositionCheck.pm $
 #------------------------------------------------------------------------------
 #*
 #  Filter and check pairs of CIF and Fobs files for suitability for
@@ -242,10 +242,9 @@ sub filter_and_check
                 if( defined $parsed ) {
                     for( $parsed->{message} ) {
                         if( $deposition_type ne 'published' &&
-                            ( /'(_journal_name_full|_publ_author_name)' was not found/ ||
-                              /'(_journal_name_full|_publ_author_name)' value .* does not provide sufficient information/ ||
-                              /neither data item '_journal_year' nor data item '_journal_volume' was found/ ||
-                              /neither data item '_journal_page_first' nor data item '_journal_article_reference' was found/ ||
+                            ( /(_journal_name_full|_publ_author_name) is undefined/ ||
+                              /neither _journal_year nor _journal_volume is defined/ ||
+                              /neither _journal_page_first nor _journal_article_reference is defined/ ||
                               /recommended data item '_publ_author_name' was not found/
                          ) ) {
                             next CCCMESSAGE;
@@ -618,7 +617,7 @@ sub filter_and_check
     }
 
     my $year = `date +%Y`;
-    $year =~ /([0-9]+)/;
+    $year =~ /(\d+)/;
     $year = $1;
 
     @filter_opt = ();
@@ -1194,7 +1193,7 @@ sub find_cif_datablock_for_hkl
                     $cif_parameters{$tag}->[0],
                     $hkl_parameters{$tag}->[0] ) ) {
                     critical( $cif_filename, undef, 'ERROR',
-                              'cannot confirm relation ' .
+                              'can not confirm relation ' .
                               'between data blocks named \'' .
                               $hkl_dataname .
                               '\' from supplied CIF and Fobs ' .
@@ -1214,7 +1213,7 @@ sub find_cif_datablock_for_hkl
                 $hkl_authors =~ s/\s//g;
                 if( $cif_authors ne $hkl_authors ) {
                     critical( $cif_filename, undef, 'ERROR',
-                              'cannot confirm relation ' .
+                              'can not confirm relation ' .
                               'between data blocks named \'' .
                               $hkl_dataname .
                               '\' from supplied CIF and Fobs ' .
@@ -1230,7 +1229,7 @@ sub find_cif_datablock_for_hkl
                 if( $cif_parameters{$tag}->[0] ne
                     $hkl_parameters{$tag}->[0] ) {
                     critical( $cif_filename, undef, 'ERROR',
-                              'cannot confirm relation ' .
+                              'can not confirm relation ' .
                               'between data blocks named \'' .
                               $hkl_dataname .
                               '\' from supplied CIF and Fobs ' .
