@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-18 11:08:55 +0200 (Mon, 18 Nov 2019) $ 
-#$Revision: 7429 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/Data/CellContents.pm $
+#$Date: 2018-07-17 17:28:29 +0300 (An, 17 liep. 2018) $ 
+#$Revision: 6311 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Data/CellContents.pm $
 #------------------------------------------------------------------------------
 #*
 #  Calculate unit cell contents from the atomic coordinates and
@@ -76,7 +76,7 @@ sub cif_cell_contents( $$@ )
 
     my $sym_atoms =
         symop_generate_atoms( \@sym_operators, $atoms, $ortho_matrix,
-                              { use_special_position_disorder => 1 } );
+                              { disregard_symmetry_independent_sites => 1 } );
 
     ## serialiseRef( $sym_atoms );
 
@@ -144,7 +144,7 @@ sub atomic_composition($$$@)
             $atom->{atom_site_occupancy} ne '.' &&
             $atom->{atom_site_occupancy} ne '?'
                 ? $atom->{atom_site_occupancy} : 1;
-        $occupancy =~ s/\([0-9]+\)\s*$//;
+        $occupancy =~ s/\(\d+\)\s*$//;
 
         my $attached_hydrogens = 0;
         if( exists $atom->{attached_hydrogens} &&
