@@ -1,13 +1,13 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-15 17:58:23 +0200 (Fri, 15 Nov 2019) $
-#$Revision: 7411 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/Data/SymmetryGenerator.pm $
+#$Date: 2017-11-22 16:23:28 +0200 (Tr, 22 lapkr. 2017) $ 
+#$Revision: 1551 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Data/SymmetryGenerator.pm $
 #------------------------------------------------------------------------------
 #*
 #  Calculate unit cell contents from the atomic coordinates and
-#  symmetry information in the CIF data structure as returned by the
-#  COD::CIF::Parser.
+#  symmetry information in the CIF data structure returned by the
+#  CIFParser.
 #**
 
 package COD::CIF::Data::SymmetryGenerator;
@@ -62,7 +62,7 @@ sub symop_generate_atoms($$$@);
 sub symop_register_applied_symop($$@);
 sub symops_apply_modulo1($$@);
 sub test_bond($$$$$);
-sub test_bump($$$$$$$@);
+sub test_bump($$$$$$$);
 sub translate_atom($$);
 sub translation($$);
 sub trim_polymer($$);
@@ -202,7 +202,6 @@ sub symop_register_applied_symop($$@)
     # FIXME: the symmetry operation list is currently optional in the
     # atom object. The following code fails if the list is not provided
     $new_atom_info->{symop} = $symop_now;
-    print STDERR ">>>> $symop_string\n" unless exists $new_atom_info->{symop_list}{symop_ids}{$symop_string};
     $new_atom_info->{symop_id} =
         $new_atom_info->{symop_list}
                         {symop_ids}
@@ -277,7 +276,7 @@ sub symops_apply_modulo1($$@)
         serialiseRef( $sym_operators );
     } if 0;
 
-    if( $options->{use_special_position_disorder} ||
+    if( $options->{disregard_symmetry_independent_sites} ||
         !exists $atom->{group} || $atom->{group} !~ /^-/ ) {
         for my $symop ( @{$sym_operators} ) {
             my $new_atom = symop_apply( $atom, $symop,
@@ -309,12 +308,12 @@ sub symops_apply_modulo1($$@)
         push( @sym_atoms, $new_atom );
     }
 
-    ## print STDERR ">>> $gp_multiplicity / $multiplicity_ratio\n";
+    ## print ">>> $gp_multiplicity / $multiplicity_ratio\n";
 
     if( $gp_multiplicity % $multiplicity_ratio ) {
         die "ERROR, multiplicity ratio $multiplicity_ratio does not divide "
           . "multiplicity of a general position $gp_multiplicity -- "
-          . "this cannot be\n";
+          . "this can not be\n";
     }
 
     my $multiplicity = $gp_multiplicity / $multiplicity_ratio;
@@ -524,23 +523,17 @@ sub test_bond($$$$$)
 #                     valency => [1],
 #                     },
 #          );
-#
-# Optionally, it accepts label (hash key) in the atom property hash
-# which holds the radius to be used for checking. Default is
-# "covalent_radius".
 
-sub test_bump($$$$$$$@)
+sub test_bump($$$$$$$)
 {
     my ( $atom_properties, $chemical_type1, $chemical_type2,
          $atom1_label, $atom2_label,
-         $dist, $bump_factor, $radius_type ) = @_;
+         $dist, $bump_factor ) = @_;
 
-    $radius_type = "covalent_radius" if !defined $radius_type;
-    
-    my $radius1 = $atom_properties->{$chemical_type1}->{$radius_type};
-    my $radius2 = $atom_properties->{$chemical_type2}->{$radius_type};
+    my $cov_radius1 = $atom_properties->{$chemical_type1}->{covalent_radius};
+    my $cov_radius2 = $atom_properties->{$chemical_type2}->{covalent_radius};
 
-    if( $dist < $bump_factor * ($radius1 + $radius2) &&
+    if( $dist < $bump_factor * ($cov_radius1 + $cov_radius2) &&
         ($dist > $special_position_cutoff ||
          $atom1_label ne $atom2_label)) {
         return 1;
@@ -567,20 +560,13 @@ sub chemical_formula_sum($@)
     $Z = 1 unless defined $Z;
 
     my %chemical_types;
-    my %label_symop_pairs;
 
     foreach my $atom (@{$atoms}) {
-        # Additional data fields for correct chemical formula calculations:
-        # 'symop_id', 'site_label'.
-        my $symop_id = $atom->{symop_id};
-        my $site_label = $atom->{site_label};
         my $chemical_type = $atom->{chemical_type};
         next if $chemical_type eq '.';
         $chemical_types{$chemical_type} = 0
-            unless defined $chemical_types{$chemical_type};
+            if !defined $chemical_types{$chemical_type};
         $chemical_types{$chemical_type}++
-            unless exists $label_symop_pairs{$site_label}{$symop_id};
-        $label_symop_pairs{$site_label}{$symop_id}++;
     }
 
     for my $chemical_type (keys %chemical_types) {
