@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-15 17:58:23 +0200 (Fri, 15 Nov 2019) $ 
-#$Revision: 7411 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.11/src/lib/perl5/COD/UserMessage.pm $
+#$Date: 2018-08-06 16:43:25 +0300 (Pr, 06 rugp. 2018) $ 
+#$Revision: 6375 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/UserMessage.pm $
 #------------------------------------------------------------------------------
 #*
 #  Format run time error and warning messages in a uniform way.
@@ -105,7 +105,7 @@ sub parse_message($)
              ($program):[ ]?
              (?:
                  ($file_name)
-                     (?: \( ([0-9]+) (?:,([0-9]+))? \) )?
+                     (?: \( (\d+) (?:,(\d+))? \) )?
                      (?: [ ]([^:]+?) )?
              )?
              :[ ]?
