@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
-#$Author: antanas $
-#$Date: 2019-12-11 15:43:02 +0200 (Wed, 11 Dec 2019) $ 
-#$Revision: 7586 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/Tags/COD.pm $
+#$Author: andrius $
+#$Date: 2019-01-21 09:23:55 +0200 (Pr, 21 saus. 2019) $ 
+#$Revision: 6648 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Tags/COD.pm $
 #------------------------------------------------------------------------
 #* 
 #  A list of CIF dictionary tags.
@@ -19,7 +19,6 @@ our @EXPORT_OK = qw(
     @tag_list
 );
 
-# Extracted from DDL1 cod_cif.dic dictionary version 0.040
 our @tag_list = qw (
 _[local]_cod_duplicate_entry
 _[local]_cod_data_source_file
@@ -45,10 +44,6 @@ _[local]_cod_text
 
 _cod_enantiomer_of
 _cod_duplicate_entry
-_cod_changelog_entry_author
-_cod_changelog_entry_date
-_cod_changelog_entry_id
-_cod_changelog_entry_text
 _cod_data_source_file
 _cod_data_source_block
 _cod_data_source_URI
@@ -58,13 +53,6 @@ _cod_data_source_MD5_sum
 _cod_data_source_SHA1_sum
 _cod_data_source_SHA256_sum
 _cod_depositor_comments
-_cod_depositor_requested_release_date
-_cod_entry_issue_author
-_cod_entry_issue_date
-_cod_entry_issue_description
-_cod_entry_issue_id
-_cod_entry_issue_origin
-_cod_entry_issue_severity
 _cod_error_flag
 _cod_error_source
 _cod_error_description
@@ -82,13 +70,9 @@ _cod_original_formula_units_Z
 _cod_original_formula_weight
 _cod_same_crystal_as
 _cod_struct_determination_method
-_cod_structure_determination_method
 _cod_suboptimal_structure
 _cod_related_optimal_struct
 _cod_related_suboptimal_struct
-_cod_related_diffrn_file_code
-_cod_related_duplicate_entry_code
-_cod_related_enantiomer_entry_code
 _cod_related_entry
 _cod_related_entry_id
 _cod_related_entry_code
@@ -98,14 +82,8 @@ _cod_related_entry_uri
 _cod_chemical_formula_sum_orig
 _cod_chemical_formula_moiety_orig
 _cod_citation_special_details
-_cod_related_optimal_entry_code
-_cod_related_same_structure_entry_code
-_cod_related_structure_entry_code
-_cod_related_suboptimal_entry_code
 _cod_text
 _cod_database_code
-_cod_database_code_structure
-_cod_database_code_diffrn_file
 _cod_database_fobs_code
 _cod_database_coordinates_code
 _cod_hold_until_date
