@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2020-05-18 22:09:57 +0300 (Mon, 18 May 2020) $ 
-#$Revision: 7969 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/Tags/Excluded.pm $
+#$Date: 2015-11-08 10:28:29 +0200 (Sk, 08 lapkr. 2015) $ 
+#$Revision: 4227 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Tags/Excluded.pm $
 #------------------------------------------------------------------------
 #* 
 #  A list of CIF dictionary tags excluded from COD files.
@@ -78,85 +78,21 @@ _vrf_[]
 _vrf_VALIDATOR_comments
 );
 
-##
-# The following data names where extracted from the 'cif_ccdc'.dic' dictionary.
-# Metadata of the source dictionary:
-#
-# Dictionary name: cif_ccdc.dic
-# Dictionary version: 1.3
-# Last updated on: 2014-05-12
-# Retrieved on: 2020-05-18
-# Retrieved from: ftp://ftp.iucr.org/pub/cifdics/cif_ccdc.dic
-##
-my @ccdc_dic_tags = qw(
-_ccdc_depnum_archive
-_ccdc_depnum_russian
-_ccdc_geom_angle
-_ccdc_geom_angle_atom_site_label_1
-_ccdc_geom_angle_atom_site_label_2
-_ccdc_geom_angle_atom_site_label_3
-_ccdc_geom_angle_fragment_id
-_ccdc_geom_angle_parameter_label
-_ccdc_geom_angle_query_id
-_ccdc_geom_angle_site_symmetry_1
-_ccdc_geom_angle_site_symmetry_2
-_ccdc_geom_angle_site_symmetry_3
-_ccdc_geom_angle_transformation
-_ccdc_geom_bond_type
-_ccdc_geom_distance
-_ccdc_geom_distance_atom_site_label_1
-_ccdc_geom_distance_atom_site_label_2
-_ccdc_geom_distance_fragment_id
-_ccdc_geom_distance_parameter_label
-_ccdc_geom_distance_query_id
-_ccdc_geom_distance_site_symmetry_1
-_ccdc_geom_distance_site_symmetry_2
-_ccdc_geom_distance_transformation
-_ccdc_geom_torsion
-_ccdc_geom_torsion_atom_site_label_1
-_ccdc_geom_torsion_atom_site_label_2
-_ccdc_geom_torsion_atom_site_label_3
-_ccdc_geom_torsion_atom_site_label_4
-_ccdc_geom_torsion_fragment_id
-_ccdc_geom_torsion_parameter_label
-_ccdc_geom_torsion_query_id
-_ccdc_geom_torsion_site_symmetry_1
-_ccdc_geom_torsion_site_symmetry_2
-_ccdc_geom_torsion_site_symmetry_3
-_ccdc_geom_torsion_site_symmetry_4
-_ccdc_geom_torsion_transformation
-_ccdc_journal_manuscript_code
-_ccdc_publ_extra_info
-);
-
-our @ccdc_tags = (
-@ccdc_dic_tags,
-qw (
-_ccdc_biological_activity
-_ccdc_chemical_compound_source_recrystallisation
-_ccdc_chemdiag_records
-_ccdc_chemdiag_type
-_ccdc_comments
-_ccdc_compound_id
-_ccdc_disorder
-_ccdc_journal_depnumber
-_ccdc_polymorph
-_citation_database_id_CSD
-_database_code_ccdc
-_database_code_CSD
-_database.code_CSD
+our @ccdc_tags = qw (
 _database_code_depnum_ccdc_archive
 _database.code_depnum_ccdc_archive
 _database_code_depnum_ccdc_fiz
 _database.code_depnum_ccdc_fiz
 _database_code_depnum_ccdc_journal
 _database.code_depnum_ccdc_journal
-_database_code_depnum_csd_archive
-)
+_ccdc_compound_id
+_database_code_ccdc
+_ccdc_disorder
+_database_code_CSD
+_database.code_CSD
 );
 
 our @icsd_tags = qw (
-_database_code_depnum_icsd_archive
 _database_code_ICSD
 _database.code_ICSD
 );
