@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
-#$Author: antanas $
-#$Date: 2019-12-16 14:12:47 +0200 (Mon, 16 Dec 2019) $ 
-#$Revision: 7607 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/Tags/Manage.pm $
+#$Author: andrius $
+#$Date: 2019-01-21 09:23:55 +0200 (Pr, 21 saus. 2019) $ 
+#$Revision: 6648 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Tags/Manage.pm $
 #------------------------------------------------------------------------
 #* 
 #  CIF tag management functions that work on the internal
@@ -39,30 +39,10 @@ our @EXPORT_OK = qw(
     set_loop_tag
     get_data_value
     get_aliased_value
-    contains_data_item
-    get_item_loop_index
 );
 
 sub rename_tags($$$);
 
-##
-# Evaluates if a data frame contains the specified data item.
-#
-# @param $data_frame
-#       Data frame as returned by the COD::CIF::Parser.
-# @param $tag
-#       Data name of the data item.
-# @return
-#       '1' if the data frame contain the data item,
-#       '0' otherwise.
-##
-sub contains_data_item
-{
-    my ( $data_frame, $tag ) = @_;
-
-    return defined $data_frame->{'values'}{$tag} ? 1 : 0;
-}
-
 sub exclude_tag
 {
     my ($cif, $tag) = @_;
@@ -86,17 +66,16 @@ sub exclude_tag
 sub tag_is_empty
 {
     my ($cif, $tag) = @_;
+    my $is_empty =1;
 
-    return 1 if !contains_data_item( $cif, $tag );
-
-    my $is_empty = 1;
-    for my $val (@{$cif->{values}{$tag}}) {
-        if( defined $val && $val ne '?' && $val ne '.' ) {
-            $is_empty = 0;
-            last;
+    if( exists $cif->{values}{$tag} ) {
+        for my $val (@{$cif->{values}{$tag}}) {
+            if( defined $val && $val ne '?' && $val ne '.' ) {
+                $is_empty = 0;
+                last;
+            }
         }
     }
-        
     return $is_empty;
 }
 
@@ -138,17 +117,16 @@ sub exclude_empty_non_loop_tags
 sub tag_is_unknown
 {
     my ($cif, $tag) = @_;
-
-    return 1 if !contains_data_item( $cif, $tag );
     my $is_empty =1;
 
-    for my $val (@{$cif->{values}{$tag}}) {
-        if( defined $val && $val ne '?' ) {
-            $is_empty = 0;
-            last;
+    if( exists $cif->{values}{$tag} ) {
+        for my $val (@{$cif->{values}{$tag}}) {
+            if( defined $val && $val ne '?' ) {
+                $is_empty = 0;
+                last;
+            }
         }
     }
-
     return $is_empty;
 }
 
@@ -199,7 +177,7 @@ sub exclude_misspelled_tags
     }
     my %misspelled_tags = map { $_ => 1 } @misspelled_tags;
     for my $misspelled_tag (@misspelled_tags) {
-        next if !contains_data_item( $cif, $misspelled_tag );
+        next if !exists $cif->{values}{$misspelled_tag};
         if( !exists $cif->{inloop}{$misspelled_tag} ) {
             exclude_tag( $cif, $misspelled_tag );
         } else {
@@ -223,37 +201,26 @@ sub exclude_misspelled_tags
 
 sub new_datablock
 {
-    my( $dataname, $cifversion ) = @_;
+    my( $dataname ) = @_;
 
-    die 'data block name cannot be empty' if !$dataname;
+    die 'data block name can not be empty' if !$dataname;
 
-    my $dataname_old = $dataname;
-    $dataname =~ s/[ \t\r\n]/_/g;
-    if( $dataname ne $dataname_old ) {
-        warn "data block name '$dataname_old' was renamed to " .
-             "'$dataname' as data block names cannot contain spaces";
-    }
-
-    my( $major, $minor ) = ( 1, 1 );
-    if( $cifversion ) {
-        ( $major, $minor, my @rest ) = split /\./, $cifversion;
-        warn 'patch version for CIF format is ignored' if @rest;
-        $major = int( $major );
-        $minor = int( $minor );
-        if( "$major.$minor" ne '1.1' && "$major.$minor" ne '2.0' ) {
-            die "unknown CIF format version '$cifversion'";
-        }
+    my $dataname_now = $dataname;
+    $dataname_now =~ s/[ \t\r\n]/_/g;
+    if( $dataname ne $dataname_now ) {
+        warn "data block name '$dataname' was renamed to " .
+             "'$dataname_now' as data block names can not contain spaces";
     }
 
     return {
-        name   => $dataname,
+        name   => $dataname_now,
         tags   => [],
         values => {},
         types  => {},
         precisions => {},
         loops  => [],
         inloop => {},
-        cifversion => { major => $major, minor => $minor }
+        cifversion => { major => 1, minor => 1 }
     };
 }
 
@@ -266,7 +233,7 @@ sub order_tags
     # Correct non-loop tags + _publ_author_name
 
     for my $tag (@{$tags_to_print}) {
-        if(  contains_data_item( $cif, $tag ) &&
+        if(  exists $cif->{values}{$tag} &&
              exists $dictionary_tags->{$tag} &&
            (!exists $cif->{inloop}{$tag} ||
             $tag eq '_publ_author_name') ) {
@@ -286,7 +253,7 @@ sub order_tags
     # Correct loop tags
 
     for my $tag (@{$loop_tags_to_print}) {
-        if( contains_data_item( $cif, $tag ) &&
+        if( exists $cif->{values}{$tag} &&
             exists $cif->{inloop}{$tag} &&
             $tag ne '_publ_author_name' ) {
             push @new_tag_list, $tag;
@@ -360,7 +327,7 @@ sub rename_tag
 {
     my ($cif, $old_tag, $new_tag ) = @_;
 
-    return if !contains_data_item( $cif, $old_tag );
+    return if !exists $cif->{values}{$old_tag};
 
     $cif->{values}{$new_tag} = $cif->{values}{$old_tag};
     delete $cif->{values}{$old_tag} if $new_tag ne $old_tag;
@@ -421,9 +388,11 @@ sub rename_tags($$$)
 {
     my ( $dataset, $tags2rename, $prefix ) = @_;
 
+    my $values = $dataset->{values};
     my %renamed_tags = ();
+
     for my $tag (@{$tags2rename}) {
-        next if !contains_data_item( $dataset, $tag );
+        next if !exists $values->{$tag};
         next if exists $dataset->{inloop}{$tag};
 
         my $new_tag = $prefix . $tag;
@@ -437,8 +406,7 @@ sub rename_tags($$$)
 sub set_tag
 {
     my ( $cif, $tag, $value ) = @_;
-
-    if ( !contains_data_item( $cif, $tag ) ) {
+    if( !exists $cif->{values}{$tag} ) {
         push @{$cif->{tags}}, $tag;
     }
     $cif->{values}{$tag}[0] = $value;
@@ -450,7 +418,7 @@ sub set_tag
 # Sets a looped data value in a data block structure.
 #
 # @param $cif
-#       The data block structure as returned by the COD::CIF::Parser.
+#       The data block structure as returned by the CIF::COD::Parser.
 # @param $tag
 #       The name of the data item that should be placed in a loop.
 # @param $in_loop
@@ -567,7 +535,7 @@ sub cifversion($)
 # according to CIF notation.
 #
 # @param $frame
-#       Data frame that contains the data item as returned by the COD::CIF::Parser.
+#       Data frame that contains the data item as returned by the CIF::COD::Parser.
 # @param $data_name
 #       Name of the data item.
 # @param $index
@@ -591,7 +559,7 @@ sub has_unknown_value
 # according to CIF notation.
 #
 # @param $frame
-#       Data frame that contains the data item as returned by the COD::CIF::Parser.
+#       Data frame that contains the data item as returned by the CIF::COD::Parser.
 # @param $data_name
 #       Name of the data item.
 # @param $index
@@ -615,7 +583,7 @@ sub has_inapplicable_value
 # inapplicable) value according to CIF notation.
 #
 # @param $frame
-#       Data frame that contains the data item as returned by the COD::CIF::Parser.
+#       Data frame that contains the data item as returned by the CIF::COD::Parser.
 # @param $data_name
 #       Name of the data item.
 # @param $index
@@ -636,11 +604,11 @@ sub has_special_value
 # the CIF working specification.
 #
 # @param $frame
-#       Data frame that contains the data item as returned by the COD::CIF::Parser.
+#       Data frame that contains the data item as returned by the CIF::COD::Parser.
 # @param $data_name
 #       Name of the data item.
 # @param $index
-#       The index of the data item value to be evaluated as numeric.
+#       The index of the data item value to be evaluated as unknown.
 # @return
 #       Boolean value denoting if the data item contains a numeric value.
 ##
@@ -654,24 +622,4 @@ sub has_numeric_value
     return ( $type eq 'INT' || $type eq 'FLOAT' );
 }
 
-##
-# Retrieves the index of the data loop that the data item resides in.
-#
-# @param $data_frame
-#       Data frame that contains the data item as returned by the COD::CIF::Parser.
-# @param $data_name
-#       Name of the data item.
-# @return
-#       The number of the loop that the data item resides in or
-#       'undef' if the data item does not reside in a loop.
-##
-sub get_item_loop_index
-{
-    my ( $data_frame, $data_name ) = @_;
-
-    return if !exists $data_frame->{'inloop'}{$data_name};
-
-    return $data_frame->{'inloop'}{$data_name};
-}
-
 1;
