@@ -1,12 +1,12 @@
 #------------------------------------------------------------------------
-#$Author: antanas $
-#$Date: 2019-11-18 11:08:55 +0200 (Mon, 18 Nov 2019) $ 
-#$Revision: 7429 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/CIF/Tags/Print.pm $
+#$Author: andrius $
+#$Date: 2017-10-25 18:00:27 +0300 (Tr, 25 spal. 2017) $ 
+#$Revision: 5657 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Tags/Print.pm $
 #------------------------------------------------------------------------
 #* 
-#  CIF tag management functions that work on the internal representation
-#  of a CIF file as returned by the COD::CIF::Parser module.
+#  CIF tag management functions that work on the internal
+#  representation of a CIF file returned by the CIFParser module.
 #**
 
 package COD::CIF::Tags::Print;
@@ -40,17 +40,15 @@ sub print_cif
 
     my $fold_long_fields = 0;
     my $folding_width;
-    my $is_save_block;
 
-    $flags = {} unless $flags && ref $flags eq 'HASH';
-    $fold_long_fields = $flags->{fold_long_fields}
-        if defined $flags->{fold_long_fields};
-    $folding_width = $flags->{folding_width}
-        if defined $flags->{folding_width};
-    %dictionary_tags = %{$flags->{dictionary_tags}}
-        if defined $flags->{dictionary_tags};
-    $is_save_block = $flags->{is_save_block}
-        if defined $flags->{is_save_block};
+    if( $flags && ref $flags eq "HASH" ) {
+        $fold_long_fields = $flags->{fold_long_fields}
+            if defined $flags->{fold_long_fields};
+        $folding_width = $flags->{folding_width}
+            if defined $flags->{folding_width};
+        %dictionary_tags = %{$flags->{dictionary_tags}}
+            if defined $flags->{dictionary_tags};
+    }
 
     my $cif_version = '1.1';
     if( exists $dataset->{cifversion} ) {
@@ -61,12 +59,12 @@ sub print_cif
 
     clean_cif( $dataset, $flags );
 
-    if( !$is_save_block && int $cif_version > 1 ) {
+    if( int $cif_version > 1 ) {
         print '#\#CIF_', $cif_version, "\n";
     }
 
     if( defined $dataset->{name} ) {
-        print $is_save_block ? 'save_' : 'data_', $dataset->{name}, "\n";
+        print "data_", $dataset->{name}, "\n";
     }
 
     my $tag_msg = "Tags that were not found in dictionaries";
@@ -128,16 +126,6 @@ sub print_cif
     if( $loop_tags_encountered ) {
         print "#END $loop_tag_msg\n";
     }
-
-    if( int $cif_version == 2 || !$is_save_block ) {
-        for my $save_block (@{$dataset->{save_blocks}}) {
-            print_cif( $save_block, { %$flags, is_save_block => 1 } );
-        }
-    }
-
-    if( $is_save_block ) {
-        print "save_\n";
-    }
 }
 
 #
@@ -327,7 +315,7 @@ sub sprint_value
                                             $cif_version );
             }
             if( @values ) {
-                return "\n[ @values ]";
+                return "[ @values ]";
             } else {
                 return '[ ]';
             }
@@ -338,7 +326,7 @@ sub sprint_value
                 if( ($key =~ /'''/ && $key =~ /"""/) ||
                     ($key =~ /'''/ && $key =~ /"$/) ||
                     ($key =~ /"""/ && $key =~ /'$/) ) {
-                    die "ERROR, cannot store value '$key' " .
+                    die "ERROR, can not store value '$key' " .
                         'in a quoted string' . "\n";
                 } elsif( $key =~ /'/ && $key =~ /"/ && $key =~ /'$/ ) {
                     $key = '"""' . $key . '"""';
