@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: antanas $
-#$Date: 2019-11-15 17:58:23 +0200 (Fri, 15 Nov 2019) $ 
-#$Revision: 7411 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/DateTime.pm $
+#$Author: andrius $
+#$Date: 2019-01-21 09:23:55 +0200 (Pr, 21 saus. 2019) $ 
+#$Revision: 6648 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/DateTime.pm $
 #------------------------------------------------------------------------------
 #*
 #* Parses and handles DateTime values.
@@ -63,7 +63,7 @@ sub parse_date
                         'day'   => $3,
                     );
     } else {
-        die "ERROR, value '$date_string' could not be successfully parsed as " .
+        die "ERROR, value '$date_string' could not be succesfully parsed as " .
             'an ISO standard date of the form <yyyy>-<mm>-<dd>';
     }
 
@@ -96,7 +96,7 @@ sub parse_datetime
         }
     };
     if ($@) {
-        die "ERROR, value '$datetime_string' could not be successfully " .
+        die "ERROR, value '$datetime_string' could not be succesfully " .
             'parsed as a timestamp value' . "\n";
     }
 
