@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-15 18:13:46 +0200 (Fri, 15 Nov 2019) $ 
-#$Revision: 7412 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/Precision.pm $
+#$Date: 2015-11-09 12:17:48 +0200 (Pr, 09 lapkr. 2015) $ 
+#$Revision: 4237 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/Precision.pm $
 #------------------------------------------------------------------------
 
 package COD::Precision;
@@ -47,7 +47,7 @@ sub unpack_cif_number
 {
     my( $number ) = @_;
     my $sigma;
-    if( $number =~ s/\(([0-9]+)\)$// ) {
+    if( $number =~ s/\((\d+)\)$// ) {
         $sigma = $1;
     }
     my $precision;
