@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-15 18:13:46 +0200 (Fri, 15 Nov 2019) $ 
-#$Revision: 7412 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/SOptions.pm $
+#$Date: 2016-01-12 16:22:02 +0200 (An, 12 saus. 2016) $ 
+#$Revision: 4529 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/SOptions.pm $
 #------------------------------------------------------------------------
 #* 
 #  Simple option processing package
@@ -89,8 +89,8 @@ sub get_value
 
 #-----------------------------------------------------------------------------
 
-my $integer = '[-+]? [0-9]+';
-my $float = '[-+]? ([0-9]+(\.[0-9]*)? | (\.[0-9]+)) ([eE][-+]?[0-9]+)?';
+my $integer = '[-+]? \d+';
+my $float = '[-+]? (\d+(\.\d*)? | (\.\d+)) ([eE][-+]?\d+)?';
 
 sub get_int
 {
