@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-29 13:32:48 +0200 (Fri, 29 Nov 2019) $ 
-#$Revision: 7516 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/SUsage.pm $
+#$Date: 2015-11-09 12:17:48 +0200 (Pr, 09 lapkr. 2015) $ 
+#$Revision: 4237 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/SUsage.pm $
 #------------------------------------------------------------------------
 #*
 #  Simple usage message generator.
@@ -25,10 +25,8 @@ sub usage
     my $script = shift;
     $script = $0 unless defined $script;
 
-    open my $script_fh, $script or
-        die "$0: $script: ERROR, could not open the '$script' file for " .
-            "reading -- " . lcfirst($!) . '.' . "\n";
-    while( <$script_fh> ) {
+    open( SCRIPT, $script ) or die("Could not open $script: $!");
+    while( <SCRIPT> ) {
         if( /^\s*#\*/ .. /^\s*#\*\*/ ) {
             /^\s*#\*?\*?/;
             my $line = "$'";
@@ -36,11 +34,7 @@ sub usage
             print $line;
         }
     }
-    close $script_fh or
-        die "$0: $script: ERROR, error occurred while closing the '$script' " .
-            "file after reading -- " . lcfirst($!) . '.' . "\n";
-
-    return;
+    close( SCRIPT );
 }
 
 sub options
@@ -50,10 +44,8 @@ sub options
 
     print "$script: The '--options' option is a placehoder.\n";
     print "$script: It should be replaced by one of the following options:\n";
-    open my $script_fh, $script or
-        die "$0: $script: ERROR, could not open the '$script' file for " .
-            "reading -- " . lcfirst($!) . '.' . "\n";
-    while( <$script_fh> ) {
+    open( SCRIPT, $0 ) or die $!;
+    while( <SCRIPT> ) {
         if( /^#\*\s+OPTIONS:/../^#\*\*/ ) {
             s/^#\*\s+OPTIONS://;
             s/^#\*\*?//;
@@ -61,11 +53,7 @@ sub options
             print;
         }
     }
-    close $script_fh or
-        die "$0: $script: ERROR, error occurred while closing the '$script' " .
-            "file after reading -- " . lcfirst($!) . '.' . "\n";
-
-    return;
+    close( SCRIPT );
 }
 
 1;
