@@ -1,13 +1,13 @@
 #------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-18 11:08:55 +0200 (Mon, 18 Nov 2019) $ 
+#$Date: 2015-11-12 13:22:42 +0200 (Kt, 12 lapkr. 2015) $ 
 #$Header:
 #$Locker:  $
 #$Log: ShowStruct.pm,v $
 #Revision 1.3  1997/09/03 15:56:59  saulius
 #RCS header added
 #
-#$Revision: 7429 $
+#$Revision: 4271 $
 #$Source: /home/saulius/src/perl-modules/ShowStruct/RCS/ShowStruct.pm,v $
 #$State: Exp $
 #------------------------------------------------------------------------
@@ -53,12 +53,7 @@ sub showHash
       }
    }
    if( $isFlat ) {
-       print '{ ' . (
-                join ' ',
-                    map { defined $hash->{$_} ?
-                                 "$_ $hash->{$_}" :
-                                 "$_ undef" } sort keys %{$hash}
-              ) . ' }';
+      print STDOUT "{ @{[%$hash]} }";
    } else {
       printf STDOUT "\n" unless $ident eq "";
       foreach my $key ( keys %{$hash} ) {
@@ -97,13 +92,13 @@ sub showArray
        my $index = 1;
        foreach my $item ( @{$array} ) {
            if( !defined $item  ) {
-               printf STDOUT "%s%-3s%-17s\n", $ident, $index++, 'undef';
+               printf STDOUT "   %s%-3d: ", "undef", $index++;
            } elsif( ref $item eq "HASH" ) {
                printf STDOUT "   %s%-3d: ", $ident, $index++;
-               showHash( $item, $ident );
+               showHash( $item, $ident . "   " );
            } elsif( ref $item eq "ARRAY" ) {
                printf STDOUT "   %s%-3d: ", $ident, $index++;
-               showArray( $item, $ident );
+               showArray( $item, $ident . "   " );
            } else {
                printf STDOUT "%s%-3s%-17s\n", $ident, $index++, $item; 
            }
