@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: antanas $
-#$Date: 2019-11-15 18:13:46 +0200 (Fri, 15 Nov 2019) $ 
-#$Revision: 7412 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/Spacegroups/Cosets.pm $
+#$Author: andrius $
+#$Date: 2018-07-18 15:38:21 +0300 (Tr, 18 liep. 2018) $ 
+#$Revision: 6322 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/Spacegroups/Cosets.pm $
 #------------------------------------------------------------------------------
 #*
 #  Perl package to find cosets of a subgroup in a symmetry group.
@@ -23,7 +23,6 @@ require Exporter;
 our @ISA = qw( Exporter );
 our @EXPORT_OK = qw(
     find_left_cosets
-    find_right_cosets
     canonical_string_from_symop
 );
 
@@ -123,7 +122,7 @@ sub find_left_cosets
                 symop_mul( $current_symop, $subgroup_symop ));
             my $coset_symop_key = canonical_string_from_symop( $coset_symop );
             ## print ">>> Coset element: ", $coset_symop_key, " ";
-            die "could not find operator '$coset_symop_key'" unless exists $group_symops{$coset_symop_key};
+            die unless exists $group_symops{$coset_symop_key};
             push( @coset, $group_symops{$coset_symop_key} );
             delete $group_symops{$coset_symop_key};
         }
