@@ -1,8 +1,8 @@
 #--*-perl-*-------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-15 18:13:46 +0200 (Fri, 15 Nov 2019) $
-#$Revision: 7412 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/Spacegroups/Symop/Algebra.pm $
+#$Date: 2015-12-18 13:08:28 +0200 (Pn, 18 gruod. 2015) $
+#$Revision: 4486 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/Spacegroups/Symop/Algebra.pm $
 #-----------------------------------------------------------------------
 #*
 # Basic symmetry operator algebra (addition, multiplication, etc.)
@@ -22,7 +22,6 @@ our @EXPORT_OK = qw(
     symop_vector_mul
     symop_invert
     symop_modulo_1
-    snap_to_crystallographic
     symop_translation
     symop_translate
     symop_set_translation
@@ -31,7 +30,6 @@ our @EXPORT_OK = qw(
     flush_zeros_in_symop
     symop_is_inversion
     symop_matrices_are_equal
-    symops_are_equal
     symop_is_translation
     symop_det round_values_in_symop
 );
@@ -83,62 +81,6 @@ sub symop_modulo_1($)
     return \@result;
 }
 
-sub snap_number_to_crystallographic
-    # Round symop matrix values to the nearest "crystallographic"
-    # value.
-{
-    my ($value, $eps) = @_;
-
-    $eps = 1E-6 unless defined $eps;
-
-    if( abs($value) < $eps ) {
-        return 0.0;
-    }
-    if( abs($value - 1) < $eps ) {
-        return 1.0;
-    }
-    if( abs($value - 1/2) < $eps ) {
-        return 1/2;
-    }
-    if( abs($value - 1/3) < $eps ) {
-        return 1/3;
-    }
-    if( abs($value - 2/3) < $eps ) {
-        return 2/3;
-    }
-    if( abs($value - 1/4) < $eps ) {
-        return 1/4;
-    }
-    if( abs($value - 3/4) < $eps ) {
-        return 3/4;
-    }
-    if( abs($value - 1/6) < $eps ) {
-        return 1/6;
-    }
-    if( abs($value - 5/6) < $eps ) {
-        return 5/6;
-    }
-    if( abs($value - 1.0) < $eps ) {
-        return 1;
-    }
-
-    return $value;
-}
-
-sub snap_to_crystallographic
-{
-    my ($vector) = @_;
-
-    for(@$vector) {
-        if( ref $_ ) {
-            snap_to_crystallographic( $_ );
-        } else {
-            $_ = snap_number_to_crystallographic( $_ );
-        }
-    }
-    return $vector;
-}
-
 sub symop_translate($$)
 {
     my ( $symop, $vector ) = @_;
@@ -262,19 +204,12 @@ sub symop_is_translation
     return 1;
 }
 
-sub matrices_are_equal
-    # Compare two matrices of they are equal. The '$n' parameter
-    # specifies the size of the matrix to be compared; the actual $s1
-    # and $s2 matrices may be larger than that; in this case only
-    # upper left square sub-matrces of size $n will be compared.
-    #
-    # N.B. Floats, if present, will be compared to equality; special
-    # care must be taken to eliminate rounding errors
+sub symop_matrices_are_equal
 {
-    my ($s1, $s2, $n) = @_;
+    my ($s1, $s2) = @_;
 
-    for( my $i = 0; $i < $n; $i++ ) {
-        for( my $j = 0; $j < $n; $j++ ) {
+    for( my $i = 0; $i < 3; $i++ ) {
+        for( my $j = 0; $j < 3; $j++ ) {
             if( $s1->[$i][$j] != $s2->[$i][$j] ) {
                 return 0;
             }
@@ -283,22 +218,6 @@ sub matrices_are_equal
     return 1;
 }
 
-
-sub symop_matrices_are_equal
-    # Compare only the rotation part of the symmetry operator.
-{
-    my ($s1, $s2) = @_;
-    return matrices_are_equal( $s1, $s2, 3 );
-}
-
-sub symops_are_equal
-    # Compare full symmetry operators (4x4 matrices), which includes
-    # both rotation and translation parts.
-{
-    my ($s1, $s2) = @_;
-    return matrices_are_equal( $s1, $s2, 4 );
-}
-
 sub symop_translation($)
 {
     my ( $symop ) = @_;
