@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
-#$Author: antanas $
-#$Date: 2019-11-18 11:08:55 +0200 (Mon, 18 Nov 2019) $ 
-#$Revision: 7429 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/Spacegroups/Symop/Parse.pm $
+#$Author: andrius $
+#$Date: 2018-07-18 15:30:39 +0300 (Tr, 18 liep. 2018) $ 
+#$Revision: 6321 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/Spacegroups/Symop/Parse.pm $
 #------------------------------------------------------------------------
 #* 
 #**
@@ -63,7 +63,7 @@ sub symop_from_string
                 $symop[$n][2] = $sign;
             }
             else {
-                if( $value =~ m/([0-9]+)\/([0-9]+)/ ) {
+                if( $value =~ m/(\d+)\/(\d+)/ ) {
                     $value = $1 / $2;
                 }
                 $symop[$n][3] = $sign * $value;
@@ -199,7 +199,7 @@ sub is_symop_parsable
 
     my $status = 1;
 
-    my $symop_term = '(?:x|y|z|[0-9]|[0-9]*\.[0-9]+|[0-9]+\.[0-9]*|[0-9]/[0-9])';
+    my $symop_term = '(?:x|y|z|\d|\d*\.\d+|\d+\.\d*|\d/\d)';
     my $symop_component =
         "(?:(?:-|\\+)?$symop_term|" .
         "(?:-|\\+)?$symop_term(?:-|\\+)$symop_term|" .
