@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-18 11:08:55 +0200 (Mon, 18 Nov 2019) $ 
-#$Revision: 7429 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v2.12/src/lib/perl5/COD/Spacegroups/Symop/SSGParse.pm $
+#$Date: 2015-11-09 12:17:48 +0200 (Pr, 09 lapkr. 2015) $ 
+#$Revision: 4237 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/Spacegroups/Symop/SSGParse.pm $
 #------------------------------------------------------------------------
 #* 
 # Parse symmetry operators describing Superspacegroups (N+1
@@ -59,14 +59,14 @@ sub symop_from_string
     for my $i (0..$#lines) {
         my $symop = lc($lines[$i]);
         $symop = lc($symop);
-        while( $symop ne "" && $symop =~ s/([-+]?)([x0-9.\/]+)// ) {
+        while( $symop ne "" && $symop =~ s/([-+]?)([x\d.\/]+)// ) {
             my $sign = defined $1 ? ($1 eq "-" ? -1 : +1 ) : +1;
             my $value = $2;
 
-            if( $value =~ /^x([0-9]+)/ ) {
+            if( $value =~ /^x(\d+)/ ) {
                 $symop[$i][$1-1] = $sign;
             } else {
-                if( $value =~ /([0-9]+)\/([0-9]+)/ ) {
+                if( $value =~ /(\d+)\/(\d+)/ ) {
                     $value = $1 / $2;
                 }
                 $symop[$i][$N] = $sign * $value;
@@ -204,7 +204,7 @@ sub check_symmetry_operator
 {
     my ($symop) = @_;
 
-    my $symop_term = '(?:x[0-9]+|[0-9]|[0-9]*\.[0-9]+|[0-9]+\.[0-9]*|[0-9]/[0-9])';
+    my $symop_term = '(?:x\d+|\d|\d*\.\d+|\d+\.\d*|\d/\d)';
     my $symop_component =
         "(?:[-+]?$symop_term(?:[-+]$symop_term){0,})";
 
